/*
 * Copyright (C) 2009 Chris Ball <cjb@laptop.org>
 *
 * Licensed under the GNU Lesser General Public License Version 2
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */

#include <stdio.h>
#include <sys/stat.h>
#include <glib.h>
#include <glib/gstdio.h>
#include <glib/gprintf.h>
#include <string.h>
#include <ohm-plugin.h>

gboolean
tty_in_use (OhmPlugin *plugin)
{
#define TTY1 "/dev/tty1"
#define TTY2 "/dev/tty2"

	struct stat tty1;
	struct stat tty2;
	time_t curtime;

	g_debug("in %s", G_STRFUNC);

	curtime = time(NULL);
	g_debug ("time now is %lu", (unsigned long) curtime);

	if (stat(TTY1, &tty1) >= 0) {
		g_debug ("tty1 time is %lu", (unsigned long) tty1.st_mtime);
		if (curtime-tty1.st_mtime >= 0 && curtime-tty1.st_mtime < 60) {
			/* We check for >= 0 so that a future filesystem doesn't inhibit. */
			g_debug("tty1 is in use; inhibiting screen dim.");
			ohm_plugin_conf_set_key (plugin, "suspend.fixme_inhibit", 1);
			return TRUE;
		}
	}

	if (stat(TTY2, &tty2) >= 0) {
		g_debug ("tty2 time is %lu", (unsigned long) tty2.st_mtime);
		if (curtime-tty2.st_mtime >= 0 && curtime-tty2.st_mtime < 60) {
			g_debug("tty2 is in use; inhibiting screen dim.");
			ohm_plugin_conf_set_key (plugin, "suspend.fixme_inhibit", 1);
			return TRUE;
		}
	}

	return FALSE;
}	

gint
check_model(OhmPlugin *plugin)
{
	char model_str[5];
	FILE *fp;
	static gint model;

	if (model != 0) /* Cached. */
		return model;

	fp = g_fopen("/ofw/model", "r");
	if (!fp) {
		g_warning ("Couldn't open /ofw/model.");
		return FALSE;
	}

	while (fgets(model_str, sizeof(model_str), fp) != NULL) {
		g_debug ("Model is %s.", model_str);
	}

        fclose(fp);

	if (g_ascii_strncasecmp(model_str, "C", 1) == 0) {
		g_debug ("XO1 C-series, returning 1.");
		model = 1;
		return model;
	}
	else if (g_ascii_strncasecmp(model_str, "D", 1) == 0) {
		g_debug ("XO1.5 D-series, returning 2.");
		model = 2;
		return model;
	}
	else {
		g_debug ("Unknown model, returning -1.");
		model = -1;
		return model;
	}
}


